# PyperCard - A Pythonic HyperCard for Beginner Programmers

A re-implementation of
[Adafruit's CircuitPython PYOA](https://github.com/adafruit/Adafruit_CircuitPython_PYOA)
module for non-CircuitPython computing environments. This module re-uses the
JSON specification used to create HyperCard like "stacks" of states between
which users transition in a choose-your-own-adventure style.

This is very much a first draft bodge. ;-)

## Developer Setup


